@@ -1,10 +1,5 @@
-import sys
 import unittest
 
-
-sys.path.append('../')
-
-
 from urllib3._collections import RecentlyUsedContainer as Container
 
 
@@ -111,6 +106,5 @@ class TestLRUContainer(unittest.TestCase):
         self.assertRaises(KeyError, lambda: d[5])
 
 
-
 if __name__ == '__main__':
     unittest.main()
