@@ -1,12 +1,7 @@
-import sys
 import unittest
 
 from StringIO import StringIO
 
-
-sys.path.append('../')
-
-
 from urllib3.response import HTTPResponse
 
 
